Crate rust_ethernet_ip_protocol

Crate rust_ethernet_ip_protocol 

EtherNet/IP encapsulation and CIP wire codecs.

Modules

cip
Common Industrial Protocol request and response codecs. CIP request, response, and Common Packet Format codecs.
encap
EtherNet/IP encapsulation packet codecs. EtherNet/IP encapsulation command and header codecs.
values
Logix value type codes and payload codecs. Logix atomic and structure type codes and payload codecs.

Structs

ProtocolError
Error returned when protocol data is invalid or unsupported.

Traits

Decode
Decodes a value from a byte buffer.
Encode
Encodes a value into an existing byte buffer.

Type Aliases

Result
Result type used by protocol codecs.