Module values

Module values 

Logix value type codes and payload codecs. Logix atomic and structure type codes and payload codecs.

Constants

AB_UDT
Logix abbreviated structure type marker.
ALT_STRING
CIP type code for a short string payload.
BOOL
CIP type code for BOOL.
BOOL_ARRAY_DWORD
CIP type code returned for packed BOOL array storage.
DINT
CIP type code for DINT.
INT
CIP type code for INT.
LINT
CIP type code for LINT.
LREAL
CIP type code for LREAL.
REAL
CIP type code for REAL.
SINT
CIP type code for SINT.
STANDARD_STRING_DATA_LEN
Maximum byte length of the built-in Logix STRING.DATA array.
STANDARD_STRING_HANDLE
Structure handle used by the built-in Logix STRING type.
STANDARD_STRING_PAD_LEN
Padding bytes following a built-in Logix STRING.DATA array.
STANDARD_STRING_PAYLOAD_LEN
Total encoded payload length of a built-in Logix STRING.
STRING
CIP type code for a standard string payload.
UDINT
CIP type code for UDINT.
UDT
Generic structure type marker.
UINT
CIP type code for UINT.
ULINT
CIP type code for ULINT.
USINT
CIP type code for USINT.

Functions

decode_array_element
Decodes one array element for the supplied CIP element type.
decode_payload
Decodes a value payload for the supplied CIP type code.
encode_payload
Appends a value payload without a type prefix.
encode_type_prefixed
Appends a CIP type prefix followed by the encoded value payload.
write_data_type
Returns the CIP type word used for a write request.
write_data_type_bytes
Encodes the CIP type prefix used for a write request.