Logix value type codes and payload codecs. Logix atomic and structure type codes and payload codecs.
Constants
- AB_UDT
- Logix abbreviated structure type marker.
- ALT_
STRING - CIP type code for a short string payload.
- BOOL
- CIP type code for
BOOL. - BOOL_
ARRAY_ DWORD - CIP type code returned for packed
BOOLarray storage. - DINT
- CIP type code for
DINT. - INT
- CIP type code for
INT. - LINT
- CIP type code for
LINT. - LREAL
- CIP type code for
LREAL. - REAL
- CIP type code for
REAL. - SINT
- CIP type code for
SINT. - STANDARD_
STRING_ DATA_ LEN - Maximum byte length of the built-in Logix
STRING.DATAarray. - STANDARD_
STRING_ HANDLE - Structure handle used by the built-in Logix
STRINGtype. - STANDARD_
STRING_ PAD_ LEN - Padding bytes following a built-in Logix
STRING.DATAarray. - STANDARD_
STRING_ PAYLOAD_ LEN - Total encoded payload length of a built-in Logix
STRING. - STRING
- CIP type code for a standard string payload.
- UDINT
- CIP type code for
UDINT. - UDT
- Generic structure type marker.
- UINT
- CIP type code for
UINT. - ULINT
- CIP type code for
ULINT. - USINT
- CIP type code for
USINT.
Functions
- decode_
array_ element - Decodes one array element for the supplied CIP element type.
- decode_
payload - Decodes a value payload for the supplied CIP type code.
- encode_
payload - Appends a value payload without a type prefix.
- encode_
type_ prefixed - Appends a CIP type prefix followed by the encoded value payload.
- write_
data_ type - Returns the CIP type word used for a write request.
- write_
data_ type_ bytes - Encodes the CIP type prefix used for a write request.